NcbiAligner
===========

.. currentmodule:: bioregistry.align

.. autoclass:: NcbiAligner
   :show-inheritance:

   .. rubric:: Attributes Summary

   .. autosummary::

      ~NcbiAligner.curation_header
      ~NcbiAligner.getter_kwargs
      ~NcbiAligner.key

   .. rubric:: Methods Summary

   .. autosummary::

      ~NcbiAligner.get_curation_row
      ~NcbiAligner.getter

   .. rubric:: Attributes Documentation

   .. autoattribute:: curation_header
   .. autoattribute:: getter_kwargs
   .. autoattribute:: key

   .. rubric:: Methods Documentation

   .. automethod:: get_curation_row
   .. automethod:: getter
